# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: roles.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0broles.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\ntags.proto\"`\n\x11RoleCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\"\n\x04role\x18\x02 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd3\x01\n\x12RoleCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04role\x18\x02 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"N\n\x0eRoleGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xcd\x01\n\x0fRoleGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04role\x18\x02 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"l\n\x11RoleUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\"\n\x04role\x18\x03 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd3\x01\n\x12RoleUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04role\x18\x02 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"T\n\x11RoleDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xaf\x01\n\x12RoleDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"T\n\x0fRoleListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb8\x01\n\x10RoleListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12#\n\x05roles\x18\x02 \x03(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\xd9\x03\n\x04Role\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\xf2\x01\n\x0c\x61\x63\x63\x65ss_rules\x18\x05 \x01(\tB\xdb\x01\xf2\xf8\xb3\x07\xd5\x01\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\xa9\x01\xea\xf3\xb3\x07\x0c\x61\x63\x63\x65ss_rules\xf2\xf3\xb3\x07\x11\n\x02go\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x19\n\ngo_private\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x1b\n\x0cgo_terraform\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x18\n\x04java\x12\x10List<AccessRule>\xf2\xf3\xb3\x07\"\n\x0cjson_gateway\x12\x12models.AccessRules\xba\xf4\xb3\x07\x17\x61\x63\x63\x65ssRulesDiffSuppress\xd0\xf4\xb3\x07\x01\x12#\n\nmanaged_by\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01:V\xfa\xf8\xb3\x07Q\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07G\xa2\xf3\xb3\x07\x1dtf_examples/role_resource.txt\xaa\xf3\xb3\x07 tf_examples/role_data_source.txtJ\x04\x08\x03\x10\x04\x32\xee\x03\n\x05Roles\x12Z\n\x06\x43reate\x12\x15.v1.RoleCreateRequest\x1a\x16.v1.RoleCreateResponse\"!\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x0e\xaa\xf3\xb3\x07\t/v1/roles\x12U\n\x03Get\x12\x12.v1.RoleGetRequest\x1a\x13.v1.RoleGetResponse\"%\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/roles/{id}\x12^\n\x06Update\x12\x15.v1.RoleUpdateRequest\x1a\x16.v1.RoleUpdateResponse\"%\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/roles/{id}\x12\x61\n\x06\x44\x65lete\x12\x15.v1.RoleDeleteRequest\x1a\x16.v1.RoleDeleteResponse\"(\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/roles/{id}\x12S\n\x04List\x12\x13.v1.RoleListRequest\x1a\x14.v1.RoleListResponse\" \x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x0e\xaa\xf3\xb3\x07\t/v1/roles\x1a\x1a\xca\xf9\xb3\x07\t\xc2\xf9\xb3\x07\x04Role\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02r-Ba\n\x19\x63om.strongdm.api.plumbingB\rRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_ROLECREATEREQUEST = DESCRIPTOR.message_types_by_name['RoleCreateRequest']
_ROLECREATERESPONSE = DESCRIPTOR.message_types_by_name['RoleCreateResponse']
_ROLEGETREQUEST = DESCRIPTOR.message_types_by_name['RoleGetRequest']
_ROLEGETRESPONSE = DESCRIPTOR.message_types_by_name['RoleGetResponse']
_ROLEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['RoleUpdateRequest']
_ROLEUPDATERESPONSE = DESCRIPTOR.message_types_by_name['RoleUpdateResponse']
_ROLEDELETEREQUEST = DESCRIPTOR.message_types_by_name['RoleDeleteRequest']
_ROLEDELETERESPONSE = DESCRIPTOR.message_types_by_name['RoleDeleteResponse']
_ROLELISTREQUEST = DESCRIPTOR.message_types_by_name['RoleListRequest']
_ROLELISTRESPONSE = DESCRIPTOR.message_types_by_name['RoleListResponse']
_ROLE = DESCRIPTOR.message_types_by_name['Role']
RoleCreateRequest = _reflection.GeneratedProtocolMessageType('RoleCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLECREATEREQUEST,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleCreateRequest)
  })
_sym_db.RegisterMessage(RoleCreateRequest)

RoleCreateResponse = _reflection.GeneratedProtocolMessageType('RoleCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLECREATERESPONSE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleCreateResponse)
  })
_sym_db.RegisterMessage(RoleCreateResponse)

RoleGetRequest = _reflection.GeneratedProtocolMessageType('RoleGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEGETREQUEST,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleGetRequest)
  })
_sym_db.RegisterMessage(RoleGetRequest)

RoleGetResponse = _reflection.GeneratedProtocolMessageType('RoleGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLEGETRESPONSE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleGetResponse)
  })
_sym_db.RegisterMessage(RoleGetResponse)

RoleUpdateRequest = _reflection.GeneratedProtocolMessageType('RoleUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEUPDATEREQUEST,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleUpdateRequest)
  })
_sym_db.RegisterMessage(RoleUpdateRequest)

RoleUpdateResponse = _reflection.GeneratedProtocolMessageType('RoleUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLEUPDATERESPONSE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleUpdateResponse)
  })
_sym_db.RegisterMessage(RoleUpdateResponse)

RoleDeleteRequest = _reflection.GeneratedProtocolMessageType('RoleDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEDELETEREQUEST,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleDeleteRequest)
  })
_sym_db.RegisterMessage(RoleDeleteRequest)

RoleDeleteResponse = _reflection.GeneratedProtocolMessageType('RoleDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLEDELETERESPONSE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleDeleteResponse)
  })
_sym_db.RegisterMessage(RoleDeleteResponse)

RoleListRequest = _reflection.GeneratedProtocolMessageType('RoleListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLELISTREQUEST,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleListRequest)
  })
_sym_db.RegisterMessage(RoleListRequest)

RoleListResponse = _reflection.GeneratedProtocolMessageType('RoleListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLELISTRESPONSE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleListResponse)
  })
_sym_db.RegisterMessage(RoleListResponse)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.Role)
  })
_sym_db.RegisterMessage(Role)

_ROLES = DESCRIPTOR.services_by_name['Roles']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\rRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _ROLECREATEREQUEST.fields_by_name['role']._options = None
  _ROLECREATEREQUEST.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLECREATERESPONSE.fields_by_name['meta']._options = None
  _ROLECREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLECREATERESPONSE.fields_by_name['role']._options = None
  _ROLECREATERESPONSE.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _ROLECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLECREATERESPONSE._options = None
  _ROLECREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ROLEGETREQUEST.fields_by_name['id']._options = None
  _ROLEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEGETRESPONSE.fields_by_name['meta']._options = None
  _ROLEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEGETRESPONSE.fields_by_name['role']._options = None
  _ROLEGETRESPONSE.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _ROLEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLEGETRESPONSE._options = None
  _ROLEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ROLEUPDATEREQUEST.fields_by_name['role']._options = None
  _ROLEUPDATEREQUEST.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEUPDATERESPONSE.fields_by_name['meta']._options = None
  _ROLEUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEUPDATERESPONSE.fields_by_name['role']._options = None
  _ROLEUPDATERESPONSE.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _ROLEUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLEUPDATERESPONSE._options = None
  _ROLEUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ROLEDELETEREQUEST.fields_by_name['id']._options = None
  _ROLEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEDELETERESPONSE.fields_by_name['meta']._options = None
  _ROLEDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _ROLEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLEDELETERESPONSE._options = None
  _ROLEDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ROLELISTREQUEST.fields_by_name['filter']._options = None
  _ROLELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLELISTRESPONSE.fields_by_name['roles']._options = None
  _ROLELISTRESPONSE.fields_by_name['roles']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ROLELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ROLELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLE.fields_by_name['id']._options = None
  _ROLE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLE.fields_by_name['name']._options = None
  _ROLE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ROLE.fields_by_name['tags']._options = None
  _ROLE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLE.fields_by_name['access_rules']._options = None
  _ROLE.fields_by_name['access_rules']._serialized_options = b'\362\370\263\007\325\001\260\363\263\007\001\312\363\263\007\251\001\352\363\263\007\014access_rules\362\363\263\007\021\n\002go\022\013AccessRules\362\363\263\007\031\n\ngo_private\022\013AccessRules\362\363\263\007\033\n\014go_terraform\022\013AccessRules\362\363\263\007\030\n\004java\022\020List<AccessRule>\362\363\263\007\"\n\014json_gateway\022\022models.AccessRules\272\364\263\007\027accessRulesDiffSuppress\320\364\263\007\001'
  _ROLE.fields_by_name['managed_by']._options = None
  _ROLE.fields_by_name['managed_by']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _ROLE._options = None
  _ROLE._serialized_options = b'\372\370\263\007Q\250\363\263\007\001\302\363\263\007G\242\363\263\007\035tf_examples/role_resource.txt\252\363\263\007 tf_examples/role_data_source.txt'
  _ROLES._options = None
  _ROLES._serialized_options = b'\312\371\263\007\t\302\371\263\007\004Role\312\371\263\007\007\322\371\263\007\002r-'
  _ROLES.methods_by_name['Create']._options = None
  _ROLES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\016\252\363\263\007\t/v1/roles'
  _ROLES.methods_by_name['Get']._options = None
  _ROLES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\023\252\363\263\007\016/v1/roles/{id}'
  _ROLES.methods_by_name['Update']._options = None
  _ROLES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\023\252\363\263\007\016/v1/roles/{id}'
  _ROLES.methods_by_name['Delete']._options = None
  _ROLES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\023\252\363\263\007\016/v1/roles/{id}'
  _ROLES.methods_by_name['List']._options = None
  _ROLES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\016\252\363\263\007\t/v1/roles'
  _ROLECREATEREQUEST._serialized_start=58
  _ROLECREATEREQUEST._serialized_end=154
  _ROLECREATERESPONSE._serialized_start=157
  _ROLECREATERESPONSE._serialized_end=368
  _ROLEGETREQUEST._serialized_start=370
  _ROLEGETREQUEST._serialized_end=448
  _ROLEGETRESPONSE._serialized_start=451
  _ROLEGETRESPONSE._serialized_end=656
  _ROLEUPDATEREQUEST._serialized_start=658
  _ROLEUPDATEREQUEST._serialized_end=766
  _ROLEUPDATERESPONSE._serialized_start=769
  _ROLEUPDATERESPONSE._serialized_end=980
  _ROLEDELETEREQUEST._serialized_start=982
  _ROLEDELETEREQUEST._serialized_end=1066
  _ROLEDELETERESPONSE._serialized_start=1069
  _ROLEDELETERESPONSE._serialized_end=1244
  _ROLELISTREQUEST._serialized_start=1246
  _ROLELISTREQUEST._serialized_end=1330
  _ROLELISTRESPONSE._serialized_start=1333
  _ROLELISTRESPONSE._serialized_end=1517
  _ROLE._serialized_start=1520
  _ROLE._serialized_end=1993
  _ROLES._serialized_start=1996
  _ROLES._serialized_end=2490
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: custom_headers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63ustom_headers.proto\x12\x02v1\x1a\roptions.proto\"W\n\rCustomHeaders\x12\x34\n\x0e\x63ustom_headers\x18\x01 \x03(\x0b\x32\x10.v1.CustomHeaderB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"k\n\x0c\x43ustomHeader\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05value\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06secret\x18\x03 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42i\n\x19\x63om.strongdm.api.plumbingB\x15\x43ustomHeadersPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_CUSTOMHEADERS = DESCRIPTOR.message_types_by_name['CustomHeaders']
_CUSTOMHEADER = DESCRIPTOR.message_types_by_name['CustomHeader']
CustomHeaders = _reflection.GeneratedProtocolMessageType('CustomHeaders', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMHEADERS,
  '__module__' : 'custom_headers_pb2'
  # @@protoc_insertion_point(class_scope:v1.CustomHeaders)
  })
_sym_db.RegisterMessage(CustomHeaders)

CustomHeader = _reflection.GeneratedProtocolMessageType('CustomHeader', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMHEADER,
  '__module__' : 'custom_headers_pb2'
  # @@protoc_insertion_point(class_scope:v1.CustomHeader)
  })
_sym_db.RegisterMessage(CustomHeader)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\025CustomHeadersPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _CUSTOMHEADERS.fields_by_name['custom_headers']._options = None
  _CUSTOMHEADERS.fields_by_name['custom_headers']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CUSTOMHEADERS._options = None
  _CUSTOMHEADERS._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _CUSTOMHEADER.fields_by_name['name']._options = None
  _CUSTOMHEADER.fields_by_name['name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CUSTOMHEADER.fields_by_name['value']._options = None
  _CUSTOMHEADER.fields_by_name['value']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CUSTOMHEADER.fields_by_name['secret']._options = None
  _CUSTOMHEADER.fields_by_name['secret']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CUSTOMHEADER._options = None
  _CUSTOMHEADER._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _CUSTOMHEADERS._serialized_start=43
  _CUSTOMHEADERS._serialized_end=130
  _CUSTOMHEADER._serialized_start=132
  _CUSTOMHEADER._serialized_end=239
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: health_checks.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13health_checks.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\"\x85\x01\n\x16HealthcheckListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x81\x02\n\x17HealthcheckListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x31\n\x0chealthchecks\x18\x02 \x03(\x0b\x32\x0f.v1.HealthcheckB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xf3\x02\n\x0bHealthcheck\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12$\n\x0bresource_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12&\n\rresource_name\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12 \n\x07node_id\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\tnode_name\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12 \n\x07healthy\x18\x06 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1d\n\terror_msg\x18\x07 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12>\n\ttimestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\xc1\x01\n\x0cHealthChecks\x12h\n\x04List\x12\x1a.v1.HealthcheckListRequest\x1a\x1b.v1.HealthcheckListResponse\"\'\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x15\xaa\xf3\xb3\x07\x10/v1/healthchecks\x1aG\xca\xf9\xb3\x07\x10\xc2\xf9\xb3\x07\x0bHealthcheck\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x90\x01\n\x19\x63om.strongdm.api.plumbingB\x14HealthChecksPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_HEALTHCHECKLISTREQUEST = DESCRIPTOR.message_types_by_name['HealthcheckListRequest']
_HEALTHCHECKLISTRESPONSE = DESCRIPTOR.message_types_by_name['HealthcheckListResponse']
_HEALTHCHECK = DESCRIPTOR.message_types_by_name['Healthcheck']
HealthcheckListRequest = _reflection.GeneratedProtocolMessageType('HealthcheckListRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKLISTREQUEST,
  '__module__' : 'health_checks_pb2'
  # @@protoc_insertion_point(class_scope:v1.HealthcheckListRequest)
  })
_sym_db.RegisterMessage(HealthcheckListRequest)

HealthcheckListResponse = _reflection.GeneratedProtocolMessageType('HealthcheckListResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKLISTRESPONSE,
  '__module__' : 'health_checks_pb2'
  # @@protoc_insertion_point(class_scope:v1.HealthcheckListResponse)
  })
_sym_db.RegisterMessage(HealthcheckListResponse)

Healthcheck = _reflection.GeneratedProtocolMessageType('Healthcheck', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECK,
  '__module__' : 'health_checks_pb2'
  # @@protoc_insertion_point(class_scope:v1.Healthcheck)
  })
_sym_db.RegisterMessage(Healthcheck)

_HEALTHCHECKS = DESCRIPTOR.services_by_name['HealthChecks']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\024HealthChecksPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _HEALTHCHECKLISTREQUEST.fields_by_name['filter']._options = None
  _HEALTHCHECKLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _HEALTHCHECKLISTREQUEST._options = None
  _HEALTHCHECKLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _HEALTHCHECKLISTRESPONSE.fields_by_name['healthchecks']._options = None
  _HEALTHCHECKLISTRESPONSE.fields_by_name['healthchecks']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _HEALTHCHECKLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _HEALTHCHECKLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _HEALTHCHECKLISTRESPONSE._options = None
  _HEALTHCHECKLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _HEALTHCHECK.fields_by_name['id']._options = None
  _HEALTHCHECK.fields_by_name['id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['resource_id']._options = None
  _HEALTHCHECK.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['resource_name']._options = None
  _HEALTHCHECK.fields_by_name['resource_name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['node_id']._options = None
  _HEALTHCHECK.fields_by_name['node_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['node_name']._options = None
  _HEALTHCHECK.fields_by_name['node_name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['healthy']._options = None
  _HEALTHCHECK.fields_by_name['healthy']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['error_msg']._options = None
  _HEALTHCHECK.fields_by_name['error_msg']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _HEALTHCHECK.fields_by_name['timestamp']._options = None
  _HEALTHCHECK.fields_by_name['timestamp']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK._options = None
  _HEALTHCHECK._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _HEALTHCHECKS._options = None
  _HEALTHCHECKS._serialized_options = b'\312\371\263\007\020\302\371\263\007\013Healthcheck\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _HEALTHCHECKS.methods_by_name['List']._options = None
  _HEALTHCHECKS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\025\252\363\263\007\020/v1/healthchecks'
  _HEALTHCHECKLISTREQUEST._serialized_start=88
  _HEALTHCHECKLISTREQUEST._serialized_end=221
  _HEALTHCHECKLISTRESPONSE._serialized_start=224
  _HEALTHCHECKLISTRESPONSE._serialized_end=481
  _HEALTHCHECK._serialized_start=484
  _HEALTHCHECK._serialized_end=855
  _HEALTHCHECKS._serialized_start=858
  _HEALTHCHECKS._serialized_end=1051
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: access_request_events_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import access_requests_pb2 as access__requests__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#access_request_events_history.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x15\x61\x63\x63\x65ss_requests.proto\x1a\roptions.proto\x1a\nspec.proto\"\x93\x01\n$AccessRequestEventHistoryListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x8e\x02\n%AccessRequestEventHistoryListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12:\n\x07history\x18\x02 \x03(\x0b\x32\x1d.v1.AccessRequestEventHistoryB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xa9\x02\n\x19\x41\x63\x63\x65ssRequestEventHistory\x12\x1f\n\x0b\x61\x63tivity_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12@\n\x14\x61\x63\x63\x65ss_request_event\x18\x03 \x01(\x0b\x32\x16.v1.AccessRequestEventB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\ndeleted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\x95\x02\n\x1a\x41\x63\x63\x65ssRequestEventsHistory\x12\x95\x01\n\x04List\x12(.v1.AccessRequestEventHistoryListRequest\x1a).v1.AccessRequestEventHistoryListResponse\"8\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07&\xaa\xf3\xb3\x07!/v1/access-request-events-history\x1a_\xca\xf9\xb3\x07\x1e\xc2\xf9\xb3\x07\x19\x41\x63\x63\x65ssRequestEventHistory\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-provider\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42\x9e\x01\n\x19\x63om.strongdm.api.plumbingB\"AccessRequestEventsHistoryPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_ACCESSREQUESTEVENTHISTORYLISTREQUEST = DESCRIPTOR.message_types_by_name['AccessRequestEventHistoryListRequest']
_ACCESSREQUESTEVENTHISTORYLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccessRequestEventHistoryListResponse']
_ACCESSREQUESTEVENTHISTORY = DESCRIPTOR.message_types_by_name['AccessRequestEventHistory']
AccessRequestEventHistoryListRequest = _reflection.GeneratedProtocolMessageType('AccessRequestEventHistoryListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTEVENTHISTORYLISTREQUEST,
  '__module__' : 'access_request_events_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestEventHistoryListRequest)
  })
_sym_db.RegisterMessage(AccessRequestEventHistoryListRequest)

AccessRequestEventHistoryListResponse = _reflection.GeneratedProtocolMessageType('AccessRequestEventHistoryListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTEVENTHISTORYLISTRESPONSE,
  '__module__' : 'access_request_events_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestEventHistoryListResponse)
  })
_sym_db.RegisterMessage(AccessRequestEventHistoryListResponse)

AccessRequestEventHistory = _reflection.GeneratedProtocolMessageType('AccessRequestEventHistory', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTEVENTHISTORY,
  '__module__' : 'access_request_events_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestEventHistory)
  })
_sym_db.RegisterMessage(AccessRequestEventHistory)

_ACCESSREQUESTEVENTSHISTORY = DESCRIPTOR.services_by_name['AccessRequestEventsHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\"AccessRequestEventsHistoryPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST.fields_by_name['filter']._options = None
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST._options = None
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE.fields_by_name['history']._options = None
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE.fields_by_name['history']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE._options = None
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['activity_id']._options = None
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['activity_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['timestamp']._options = None
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['timestamp']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['access_request_event']._options = None
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['access_request_event']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['deleted_at']._options = None
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['deleted_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORY._options = None
  _ACCESSREQUESTEVENTHISTORY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACCESSREQUESTEVENTSHISTORY._options = None
  _ACCESSREQUESTEVENTSHISTORY._serialized_options = b'\312\371\263\007\036\302\371\263\007\031AccessRequestEventHistory\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider\312\371\263\007\005\350\371\263\007\001'
  _ACCESSREQUESTEVENTSHISTORY.methods_by_name['List']._options = None
  _ACCESSREQUESTEVENTSHISTORY.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007&\252\363\263\007!/v1/access-request-events-history'
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST._serialized_start=127
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST._serialized_end=274
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE._serialized_start=277
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE._serialized_end=547
  _ACCESSREQUESTEVENTHISTORY._serialized_start=550
  _ACCESSREQUESTEVENTHISTORY._serialized_end=847
  _ACCESSREQUESTEVENTSHISTORY._serialized_start=850
  _ACCESSREQUESTEVENTSHISTORY._serialized_end=1127
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret_engines.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import secret_stores_pb2 as secret__stores__pb2
from . import secret_engine_types_pb2 as secret__engine__types__pb2
from . import secret_engine_policy_pb2 as secret__engine__policy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14secret_engines.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\x13secret_stores.proto\x1a\x19secret_engine_types.proto\x1a\x1asecret_engine_policy.proto\"h\n\x17SecretEngineListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xdd\x01\n\x18SecretEngineListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x34\n\x0esecret_engines\x18\x02 \x03(\x0b\x32\x10.v1.SecretEngineB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"b\n\x16SecretEngineGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xe6\x01\n\x17SecretEngineGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\rsecret_engine\x18\x02 \x01(\x0b\x32\x10.v1.SecretEngineB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x85\x01\n\x19SecretEngineCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x33\n\rsecret_engine\x18\x02 \x01(\x0b\x32\x10.v1.SecretEngineB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xec\x01\n\x1aSecretEngineCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\rsecret_engine\x18\x02 \x01(\x0b\x32\x10.v1.SecretEngineB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x91\x01\n\x19SecretEngineUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\x33\n\rsecret_engine\x18\x03 \x01(\x0b\x32\x10.v1.SecretEngineB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xec\x01\n\x1aSecretEngineUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\rsecret_engine\x18\x02 \x01(\x0b\x32\x10.v1.SecretEngineB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"h\n\x19SecretEngineDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xab\x01\n\x1aSecretEngineDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"p\n\x13GenerateKeysRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12$\n\x10secret_engine_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xa5\x01\n\x14GenerateKeysResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadata\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"l\n\x12HealthcheckRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12$\n\x10secret_engine_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"X\n\x11HealthcheckStatus\x12\x1b\n\x07node_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06status\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xd3\x01\n\x13HealthcheckResponse\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\x12\x31\n\x06status\x18\x02 \x03(\x0b\x32\x15.v1.HealthcheckStatusB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xad\x01\n\x19SecretEngineRotateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x43\n\x0fpassword_policy\x18\x03 \x01(\x0b\x32\x1e.v1.SecretEnginePasswordPolicyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xaa\x01\n\x1aSecretEngineRotateResponse\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xac\t\n\rSecretEngines\x12l\n\x04List\x12\x1b.v1.SecretEngineListRequest\x1a\x1c.v1.SecretEngineListResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/secret-engines\x12n\n\x03Get\x12\x1a.v1.SecretEngineGetRequest\x1a\x1b.v1.SecretEngineGetResponse\".\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/secret-engines/{id}\x12s\n\x06\x43reate\x12\x1d.v1.SecretEngineCreateRequest\x1a\x1e.v1.SecretEngineCreateResponse\"*\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/secret-engines\x12w\n\x06Update\x12\x1d.v1.SecretEngineUpdateRequest\x1a\x1e.v1.SecretEngineUpdateResponse\".\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/secret-engines/{id}\x12z\n\x06\x44\x65lete\x12\x1d.v1.SecretEngineDeleteRequest\x1a\x1e.v1.SecretEngineDeleteResponse\"1\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/secret-engines/{id}\x12~\n\x10ListSecretStores\x12\x1a.v1.SecretStoreListRequest\x1a\x1b.v1.SecretStoreListResponse\"1\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1f\xaa\xf3\xb3\x07\x1a/v1/secret-engines-stores/\x12\x8d\x01\n\x0cGenerateKeys\x12\x17.v1.GenerateKeysRequest\x1a\x18.v1.GenerateKeysResponse\"J\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x38\xaa\xf3\xb3\x07\x33/v1/secret-engines/{secret_engine_id}/generate-keys\x12\x88\x01\n\x0bHealthcheck\x12\x16.v1.HealthcheckRequest\x1a\x17.v1.HealthcheckResponse\"H\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x36\xaa\xf3\xb3\x07\x31/v1/secret-engines/{secret_engine_id}/healthcheck\x12~\n\x06Rotate\x12\x1d.v1.SecretEngineRotateRequest\x1a\x1e.v1.SecretEngineRotateResponse\"5\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07#\xaa\xf3\xb3\x07\x1e/v1/secret-engines/{id}/rotate\x1a\x38\xca\xf9\xb3\x07\x11\xc2\xf9\xb3\x07\x0cSecretEngine\xca\xf9\xb3\x07\t\xd2\xf9\xb3\x07\x04\x65ng-\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42i\n\x19\x63om.strongdm.api.plumbingB\x15SecretEnginesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_SECRETENGINELISTREQUEST = DESCRIPTOR.message_types_by_name['SecretEngineListRequest']
_SECRETENGINELISTRESPONSE = DESCRIPTOR.message_types_by_name['SecretEngineListResponse']
_SECRETENGINEGETREQUEST = DESCRIPTOR.message_types_by_name['SecretEngineGetRequest']
_SECRETENGINEGETRESPONSE = DESCRIPTOR.message_types_by_name['SecretEngineGetResponse']
_SECRETENGINECREATEREQUEST = DESCRIPTOR.message_types_by_name['SecretEngineCreateRequest']
_SECRETENGINECREATERESPONSE = DESCRIPTOR.message_types_by_name['SecretEngineCreateResponse']
_SECRETENGINEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['SecretEngineUpdateRequest']
_SECRETENGINEUPDATERESPONSE = DESCRIPTOR.message_types_by_name['SecretEngineUpdateResponse']
_SECRETENGINEDELETEREQUEST = DESCRIPTOR.message_types_by_name['SecretEngineDeleteRequest']
_SECRETENGINEDELETERESPONSE = DESCRIPTOR.message_types_by_name['SecretEngineDeleteResponse']
_GENERATEKEYSREQUEST = DESCRIPTOR.message_types_by_name['GenerateKeysRequest']
_GENERATEKEYSRESPONSE = DESCRIPTOR.message_types_by_name['GenerateKeysResponse']
_HEALTHCHECKREQUEST = DESCRIPTOR.message_types_by_name['HealthcheckRequest']
_HEALTHCHECKSTATUS = DESCRIPTOR.message_types_by_name['HealthcheckStatus']
_HEALTHCHECKRESPONSE = DESCRIPTOR.message_types_by_name['HealthcheckResponse']
_SECRETENGINEROTATEREQUEST = DESCRIPTOR.message_types_by_name['SecretEngineRotateRequest']
_SECRETENGINEROTATERESPONSE = DESCRIPTOR.message_types_by_name['SecretEngineRotateResponse']
SecretEngineListRequest = _reflection.GeneratedProtocolMessageType('SecretEngineListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINELISTREQUEST,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineListRequest)
  })
_sym_db.RegisterMessage(SecretEngineListRequest)

SecretEngineListResponse = _reflection.GeneratedProtocolMessageType('SecretEngineListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINELISTRESPONSE,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineListResponse)
  })
_sym_db.RegisterMessage(SecretEngineListResponse)

SecretEngineGetRequest = _reflection.GeneratedProtocolMessageType('SecretEngineGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINEGETREQUEST,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineGetRequest)
  })
_sym_db.RegisterMessage(SecretEngineGetRequest)

SecretEngineGetResponse = _reflection.GeneratedProtocolMessageType('SecretEngineGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINEGETRESPONSE,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineGetResponse)
  })
_sym_db.RegisterMessage(SecretEngineGetResponse)

SecretEngineCreateRequest = _reflection.GeneratedProtocolMessageType('SecretEngineCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINECREATEREQUEST,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineCreateRequest)
  })
_sym_db.RegisterMessage(SecretEngineCreateRequest)

SecretEngineCreateResponse = _reflection.GeneratedProtocolMessageType('SecretEngineCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINECREATERESPONSE,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineCreateResponse)
  })
_sym_db.RegisterMessage(SecretEngineCreateResponse)

SecretEngineUpdateRequest = _reflection.GeneratedProtocolMessageType('SecretEngineUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINEUPDATEREQUEST,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineUpdateRequest)
  })
_sym_db.RegisterMessage(SecretEngineUpdateRequest)

SecretEngineUpdateResponse = _reflection.GeneratedProtocolMessageType('SecretEngineUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINEUPDATERESPONSE,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineUpdateResponse)
  })
_sym_db.RegisterMessage(SecretEngineUpdateResponse)

SecretEngineDeleteRequest = _reflection.GeneratedProtocolMessageType('SecretEngineDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINEDELETEREQUEST,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineDeleteRequest)
  })
_sym_db.RegisterMessage(SecretEngineDeleteRequest)

SecretEngineDeleteResponse = _reflection.GeneratedProtocolMessageType('SecretEngineDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINEDELETERESPONSE,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineDeleteResponse)
  })
_sym_db.RegisterMessage(SecretEngineDeleteResponse)

GenerateKeysRequest = _reflection.GeneratedProtocolMessageType('GenerateKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEKEYSREQUEST,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.GenerateKeysRequest)
  })
_sym_db.RegisterMessage(GenerateKeysRequest)

GenerateKeysResponse = _reflection.GeneratedProtocolMessageType('GenerateKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEKEYSRESPONSE,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.GenerateKeysResponse)
  })
_sym_db.RegisterMessage(GenerateKeysResponse)

HealthcheckRequest = _reflection.GeneratedProtocolMessageType('HealthcheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKREQUEST,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.HealthcheckRequest)
  })
_sym_db.RegisterMessage(HealthcheckRequest)

HealthcheckStatus = _reflection.GeneratedProtocolMessageType('HealthcheckStatus', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKSTATUS,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.HealthcheckStatus)
  })
_sym_db.RegisterMessage(HealthcheckStatus)

HealthcheckResponse = _reflection.GeneratedProtocolMessageType('HealthcheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKRESPONSE,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.HealthcheckResponse)
  })
_sym_db.RegisterMessage(HealthcheckResponse)

SecretEngineRotateRequest = _reflection.GeneratedProtocolMessageType('SecretEngineRotateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINEROTATEREQUEST,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineRotateRequest)
  })
_sym_db.RegisterMessage(SecretEngineRotateRequest)

SecretEngineRotateResponse = _reflection.GeneratedProtocolMessageType('SecretEngineRotateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINEROTATERESPONSE,
  '__module__' : 'secret_engines_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngineRotateResponse)
  })
_sym_db.RegisterMessage(SecretEngineRotateResponse)

_SECRETENGINES = DESCRIPTOR.services_by_name['SecretEngines']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\025SecretEnginesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _SECRETENGINELISTREQUEST.fields_by_name['filter']._options = None
  _SECRETENGINELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINELISTREQUEST._options = None
  _SECRETENGINELISTREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINELISTRESPONSE.fields_by_name['secret_engines']._options = None
  _SECRETENGINELISTRESPONSE.fields_by_name['secret_engines']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _SECRETENGINELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETENGINELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETENGINELISTRESPONSE._options = None
  _SECRETENGINELISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINEGETREQUEST.fields_by_name['id']._options = None
  _SECRETENGINEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEGETREQUEST._options = None
  _SECRETENGINEGETREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINEGETRESPONSE.fields_by_name['meta']._options = None
  _SECRETENGINEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEGETRESPONSE.fields_by_name['secret_engine']._options = None
  _SECRETENGINEGETRESPONSE.fields_by_name['secret_engine']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETENGINEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETENGINEGETRESPONSE._options = None
  _SECRETENGINEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINECREATEREQUEST.fields_by_name['secret_engine']._options = None
  _SECRETENGINECREATEREQUEST.fields_by_name['secret_engine']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINECREATEREQUEST._options = None
  _SECRETENGINECREATEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINECREATERESPONSE.fields_by_name['meta']._options = None
  _SECRETENGINECREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINECREATERESPONSE.fields_by_name['secret_engine']._options = None
  _SECRETENGINECREATERESPONSE.fields_by_name['secret_engine']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETENGINECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETENGINECREATERESPONSE._options = None
  _SECRETENGINECREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINEUPDATEREQUEST.fields_by_name['secret_engine']._options = None
  _SECRETENGINEUPDATEREQUEST.fields_by_name['secret_engine']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEUPDATEREQUEST._options = None
  _SECRETENGINEUPDATEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINEUPDATERESPONSE.fields_by_name['meta']._options = None
  _SECRETENGINEUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEUPDATERESPONSE.fields_by_name['secret_engine']._options = None
  _SECRETENGINEUPDATERESPONSE.fields_by_name['secret_engine']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETENGINEUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETENGINEUPDATERESPONSE._options = None
  _SECRETENGINEUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINEDELETEREQUEST.fields_by_name['id']._options = None
  _SECRETENGINEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEDELETEREQUEST._options = None
  _SECRETENGINEDELETEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETENGINEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETENGINEDELETERESPONSE._options = None
  _SECRETENGINEDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _GENERATEKEYSREQUEST.fields_by_name['secret_engine_id']._options = None
  _GENERATEKEYSREQUEST.fields_by_name['secret_engine_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GENERATEKEYSREQUEST._options = None
  _GENERATEKEYSREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _GENERATEKEYSRESPONSE.fields_by_name['rate_limit']._options = None
  _GENERATEKEYSRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _GENERATEKEYSRESPONSE._options = None
  _GENERATEKEYSRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _HEALTHCHECKREQUEST.fields_by_name['secret_engine_id']._options = None
  _HEALTHCHECKREQUEST.fields_by_name['secret_engine_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _HEALTHCHECKREQUEST._options = None
  _HEALTHCHECKREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _HEALTHCHECKSTATUS.fields_by_name['node_id']._options = None
  _HEALTHCHECKSTATUS.fields_by_name['node_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _HEALTHCHECKSTATUS.fields_by_name['status']._options = None
  _HEALTHCHECKSTATUS.fields_by_name['status']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _HEALTHCHECKSTATUS._options = None
  _HEALTHCHECKSTATUS._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _HEALTHCHECKRESPONSE.fields_by_name['rate_limit']._options = None
  _HEALTHCHECKRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _HEALTHCHECKRESPONSE.fields_by_name['status']._options = None
  _HEALTHCHECKRESPONSE.fields_by_name['status']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _HEALTHCHECKRESPONSE._options = None
  _HEALTHCHECKRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINEROTATEREQUEST.fields_by_name['id']._options = None
  _SECRETENGINEROTATEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEROTATEREQUEST.fields_by_name['password_policy']._options = None
  _SECRETENGINEROTATEREQUEST.fields_by_name['password_policy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINEROTATEREQUEST._options = None
  _SECRETENGINEROTATEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINEROTATERESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETENGINEROTATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETENGINEROTATERESPONSE._options = None
  _SECRETENGINEROTATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETENGINES._options = None
  _SECRETENGINES._serialized_options = b'\312\371\263\007\021\302\371\263\007\014SecretEngine\312\371\263\007\t\322\371\263\007\004eng-\312\371\263\007\005\330\371\263\007\001\312\371\263\007\005\350\371\263\007\001'
  _SECRETENGINES.methods_by_name['List']._options = None
  _SECRETENGINES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\027\252\363\263\007\022/v1/secret-engines'
  _SECRETENGINES.methods_by_name['Get']._options = None
  _SECRETENGINES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\034\252\363\263\007\027/v1/secret-engines/{id}'
  _SECRETENGINES.methods_by_name['Create']._options = None
  _SECRETENGINES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\027\252\363\263\007\022/v1/secret-engines'
  _SECRETENGINES.methods_by_name['Update']._options = None
  _SECRETENGINES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\034\252\363\263\007\027/v1/secret-engines/{id}'
  _SECRETENGINES.methods_by_name['Delete']._options = None
  _SECRETENGINES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\034\252\363\263\007\027/v1/secret-engines/{id}'
  _SECRETENGINES.methods_by_name['ListSecretStores']._options = None
  _SECRETENGINES.methods_by_name['ListSecretStores']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\037\252\363\263\007\032/v1/secret-engines-stores/'
  _SECRETENGINES.methods_by_name['GenerateKeys']._options = None
  _SECRETENGINES.methods_by_name['GenerateKeys']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\0078\252\363\263\0073/v1/secret-engines/{secret_engine_id}/generate-keys'
  _SECRETENGINES.methods_by_name['Healthcheck']._options = None
  _SECRETENGINES.methods_by_name['Healthcheck']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\0076\252\363\263\0071/v1/secret-engines/{secret_engine_id}/healthcheck'
  _SECRETENGINES.methods_by_name['Rotate']._options = None
  _SECRETENGINES.methods_by_name['Rotate']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007#\252\363\263\007\036/v1/secret-engines/{id}/rotate'
  _SECRETENGINELISTREQUEST._serialized_start=131
  _SECRETENGINELISTREQUEST._serialized_end=235
  _SECRETENGINELISTRESPONSE._serialized_start=238
  _SECRETENGINELISTRESPONSE._serialized_end=459
  _SECRETENGINEGETREQUEST._serialized_start=461
  _SECRETENGINEGETREQUEST._serialized_end=559
  _SECRETENGINEGETRESPONSE._serialized_start=562
  _SECRETENGINEGETRESPONSE._serialized_end=792
  _SECRETENGINECREATEREQUEST._serialized_start=795
  _SECRETENGINECREATEREQUEST._serialized_end=928
  _SECRETENGINECREATERESPONSE._serialized_start=931
  _SECRETENGINECREATERESPONSE._serialized_end=1167
  _SECRETENGINEUPDATEREQUEST._serialized_start=1170
  _SECRETENGINEUPDATEREQUEST._serialized_end=1315
  _SECRETENGINEUPDATERESPONSE._serialized_start=1318
  _SECRETENGINEUPDATERESPONSE._serialized_end=1554
  _SECRETENGINEDELETEREQUEST._serialized_start=1556
  _SECRETENGINEDELETEREQUEST._serialized_end=1660
  _SECRETENGINEDELETERESPONSE._serialized_start=1663
  _SECRETENGINEDELETERESPONSE._serialized_end=1834
  _GENERATEKEYSREQUEST._serialized_start=1836
  _GENERATEKEYSREQUEST._serialized_end=1948
  _GENERATEKEYSRESPONSE._serialized_start=1951
  _GENERATEKEYSRESPONSE._serialized_end=2116
  _HEALTHCHECKREQUEST._serialized_start=2118
  _HEALTHCHECKREQUEST._serialized_end=2226
  _HEALTHCHECKSTATUS._serialized_start=2228
  _HEALTHCHECKSTATUS._serialized_end=2316
  _HEALTHCHECKRESPONSE._serialized_start=2319
  _HEALTHCHECKRESPONSE._serialized_end=2530
  _SECRETENGINEROTATEREQUEST._serialized_start=2533
  _SECRETENGINEROTATEREQUEST._serialized_end=2706
  _SECRETENGINEROTATERESPONSE._serialized_start=2709
  _SECRETENGINEROTATERESPONSE._serialized_end=2879
  _SECRETENGINES._serialized_start=2882
  _SECRETENGINES._serialized_end=4078
# @@protoc_insertion_point(module_scope)
